@@ -50,6 +50,9 @@
 #include <audiooutputengine.h>
 #include <plugingui.h>
 
+#include <texturedbox.h>
+#include <imagecache.h>
+
 class DrumGizmoPlugin
 #ifdef LV2
 	: public PluginLV2
@@ -65,8 +68,6 @@ public:
 	DrumGizmoPlugin();
 #endif
 
-	void onFreeWheelChange(bool freewheel) override;
-
 	void onFramesizeChange(size_t framesize) override;
 
 	void onSamplerateChange(float samplerate) override;
@@ -81,7 +82,13 @@ public:
 	size_t getNumberOfAudioInputs() override;
 	size_t getNumberOfAudioOutputs() override;
 
+	// Functions used to set VST plugin information
+
 	std::string getId() override;
+	std::string getEffectName() override;
+	std::string getVendorString() override;
+	std::string getProductString() override;
+	PluginCategory getPluginCategory() override;
 
 	void process(size_t pos,
 	             const std::vector<MidiEvent>& input_events,
@@ -90,6 +97,14 @@ public:
 	             const std::vector<float*>& output_samples,
 	             size_t count) override;
 
+	//
+	// Inline GUI
+	//
+	bool hasInlineGUI() override;
+	void onInlineRedraw(std::size_t width,
+	                    std::size_t max_height,
+	                    InlineDrawContext& context) override;
+
 	//
 	// GUI
 	//
@@ -108,9 +123,9 @@ private:
 	public:
 		Input(DrumGizmoPlugin& plugin);
 
-		bool init(Instruments& instruments) override;
+		bool init(const Instruments& instruments) override;
 
-		void setParm(std::string parm, std::string value) override;
+		void setParm(const std::string& parm, const std::string& value) override;
 
 		bool start() override;
 		void stop() override;
@@ -119,9 +134,11 @@ private:
 		void run(size_t pos, size_t len, std::vector<event_t>& events) override;
 		void post() override;
 
+		bool isFreewheeling() const override;
+
 	protected:
 		DrumGizmoPlugin& plugin;
-		Instruments* instruments{nullptr};
+		const Instruments* instruments{nullptr};
 	};
 
 	class Output
@@ -130,9 +147,9 @@ private:
 	public:
 		Output(DrumGizmoPlugin& plugin);
 
-		bool init(Channels channels) override;
+		bool init(const Channels& channels) override;
 
-		void setParm(std::string parm, std::string value) override;
+		void setParm(const std::string& parm, const std::string& value) override;
 
 		bool start() override;
 		void stop() override;
@@ -141,19 +158,57 @@ private:
 		void run(int ch, sample_t *samples, size_t nsamples) override;
 		void post(size_t nsamples) override;
 
-		sample_t *getBuffer(int ch) override;
-		size_t getBufferSize() override;
+		sample_t *getBuffer(int ch) const override;
+		size_t getBufferSize() const override;
+		bool isFreewheeling() const override;
 
 	protected:
 		DrumGizmoPlugin& plugin;
 	};
 
+	class ConfigStringIO
+	{
+	public:
+		ConfigStringIO(Settings& settings);
+
+		std::string get();
+		bool set(std::string config_string);
+	private:
+		Settings& settings;
+	};
+
 	Input input{*this};
 	const std::vector<MidiEvent>* input_events{nullptr};
 
 	Output output{*this};
 	const std::vector<float*>* output_samples{nullptr};
 
+	Settings settings;
+	ConfigStringIO config_string_io;
+	SettingsGetter settingsGetter{settings};
+
+	GUI::ImageCache imageCache;
+	GUI::TexturedBox box{imageCache, ":progress.png",
+			0, 0, // atlas offset (x, y)
+			6, 1, 6, // dx1, dx2, dx3
+			11, 0, 0}; // dy1, dy2, dy3
+
+	GUI::TexturedBox bar_red{imageCache, ":progress.png",
+			13, 0, // atlas offset (x, y)
+			2, 1, 2, // dx1, dx2, dx3
+			11, 0, 0}; // dy1, dy2, dy3
+
+	GUI::TexturedBox bar_green{imageCache, ":progress.png",
+			18, 0, // atlas offset (x, y)
+			2, 1, 2, // dx1, dx2, dx3
+			11, 0, 0}; // dy1, dy2, dy3
+
+	GUI::TexturedBox bar_blue{imageCache, ":progress.png",
+			23, 0, // atlas offset (x, y)
+			2, 1, 2, // dx1, dx2, dx3
+			11, 0, 0}; // dy1, dy2, dy3
+
 	std::shared_ptr<GUI::PluginGUI> plugin_gui;
 	std::shared_ptr<DrumGizmo> drumgizmo;
+	std::uint32_t inlineDisplayBuffer[1024*1024];
 };
