@@ -33,10 +33,14 @@
 #include "font.h"
 #include "listboxthin.h"
 #include "painter.h"
+#include "texturedbox.h"
 
-namespace GUI {
+namespace GUI
+{
 
-class ComboBox : public Widget {
+class ComboBox
+	: public Widget
+{
 public:
 	ComboBox(Widget* parent);
 	~ComboBox();
@@ -58,7 +62,10 @@ public:
 	Notifier<std::string, std::string> valueChangedNotifier;
 
 private:
-	Painter::Box box;
+	TexturedBox box{getImageCache(), ":widget.png",
+			0, 0, // atlas offset (x, y)
+			7, 1, 7, // dx1, dx2, dx3
+			7, 63, 7}; // dy1, dy2, dy3
 
 	void listboxSelectHandler();
 
