@@ -43,12 +43,12 @@ bool EventHandler::hasEvent()
 	return nativeWindow.hasEvent();
 }
 
-Event *EventHandler::getNextEvent()
+std::shared_ptr<Event> EventHandler::getNextEvent()
 {
 	return nativeWindow.getNextEvent();
 }
 
-Event *EventHandler::peekNextEvent()
+std::shared_ptr<Event> EventHandler::peekNextEvent()
 {
 	return nativeWindow.peekNextEvent();
 }
@@ -81,7 +81,11 @@ void EventHandler::processEvents()
 					}
 
 					auto peekEvent = peekNextEvent();
-					if(!peekEvent || (peekEvent->type() != EventType::resize))
+					if(!peekEvent)
+					{
+						break;
+					}
+					if(peekEvent->type() != EventType::resize)
 					{
 						break;
 					}
@@ -89,7 +93,7 @@ void EventHandler::processEvents()
 					event = getNextEvent();
 				}
 
-				auto resizeEvent = static_cast<ResizeEvent*>(event);
+				auto resizeEvent = static_cast<ResizeEvent*>(event.get());
 				if((resizeEvent->width != window.width()) ||
 				   (resizeEvent->height != window.height()))
 				{
@@ -108,7 +112,11 @@ void EventHandler::processEvents()
 					}
 
 					auto peekEvent = peekNextEvent();
-					if(!peekEvent || (peekEvent->type() != EventType::mouseMove))
+					if(!peekEvent)
+					{
+						break;
+					}
+					if(peekEvent->type() != EventType::mouseMove)
 					{
 						break;
 					}
@@ -116,7 +124,7 @@ void EventHandler::processEvents()
 					event = getNextEvent();
 				}
 
-				auto moveEvent = static_cast<MouseMoveEvent*>(event);
+				auto moveEvent = static_cast<MouseMoveEvent*>(event.get());
 
 				auto widget = window.find(moveEvent->x, moveEvent->y);
 				auto oldwidget = window.mouseFocus();
@@ -164,7 +172,7 @@ void EventHandler::processEvents()
 					continue;
 				}
 
-				auto buttonEvent = static_cast<ButtonEvent*>(event);
+				auto buttonEvent = static_cast<ButtonEvent*>(event.get());
 
 				lastWasDoubleClick = buttonEvent->doubleClick;
 
@@ -216,17 +224,22 @@ void EventHandler::processEvents()
 					}
 
 					auto peekEvent = peekNextEvent();
-					if(!peekEvent || (peekEvent->type() != EventType::scroll))
+					if(!peekEvent)
+					{
+						break;
+					}
+					if(peekEvent->type() != EventType::scroll)
 					{
 						break;
 					}
 
-					auto scrollEvent = static_cast<ScrollEvent*>(event);
+					auto scrollEvent = static_cast<ScrollEvent*>(event.get());
 					delta += scrollEvent->delta;
+
 					event = getNextEvent();
 				}
 
-				auto scrollEvent = static_cast<ScrollEvent*>(event);
+				auto scrollEvent = static_cast<ScrollEvent*>(event.get());
 				scrollEvent->delta += delta;
 
 				auto widget = window.find(scrollEvent->x, scrollEvent->y);
@@ -245,7 +258,7 @@ void EventHandler::processEvents()
 
 				// TODO: Filter out multiple arrow events.
 
-				auto keyEvent = static_cast<KeyEvent*>(event);
+				auto keyEvent = static_cast<KeyEvent*>(event.get());
 				if(window.keyboardFocus())
 				{
 					window.keyboardFocus()->keyEvent(keyEvent);
@@ -257,8 +270,6 @@ void EventHandler::processEvents()
 			closeNotifier();
 			break;
 		}
-
-		delete event;
 	}
 }
 
