@@ -51,13 +51,13 @@ private:
 
 	class Character {
 	public:
-		int offset{0};
-		size_t width{0};
+		std::size_t offset{0};
+		std::size_t width{0};
 		int pre_bias{0};
 		int post_bias{0};
 	};
 
-	std::array<Character, 255> characters;
+	std::array<Character, 256> characters;
 	int spacing{1};
 };
 
