@@ -27,30 +27,39 @@
 #pragma once
 
 #include <string>
+#include <vector>
 
+#include "drawable.h"
 #include "colour.h"
 #include "resource.h"
 
 namespace GUI {
 
-class Image {
+class Image
+	: public Drawable
+{
 public:
 	Image(const char* data, size_t size);
 	Image(const std::string& filename);
-	~Image();
+	Image(Image&& other);
+	virtual ~Image();
 
-	size_t width() const;
-	size_t height() const;
+	Image& operator=(Image&& other);
 
-	Colour getPixel(size_t x, size_t y) const;
+	size_t width() const override;
+	size_t height() const override;
+
+	const Colour& getPixel(size_t x, size_t y) const override;
 
 private:
 	void setError();
 
 	void load(const char* data, size_t size);
 
-	size_t _width, _height;
-	unsigned char* image_data;
+	std::size_t _width{0};
+	std::size_t _height{0};
+	std::vector<Colour> image_data;
+	Colour out_of_range{0.0f, 0.0f, 0.0f, 0.0f};
 };
 
 } // GUI::
