@@ -26,10 +26,11 @@
  */
 #pragma once
 
+#include <notifier.h>
+
 #include "widget.h"
-#include "image.h"
+#include "texture.h"
 #include "font.h"
-#include "notifier.h"
 
 namespace GUI {
 
@@ -71,7 +72,7 @@ private:
 	float maximum;
 	float minimum;
 
-	Image img_knob;
+	Texture img_knob;
 
 	int mouse_offset_x;
 	Font font;
