@@ -11,43 +11,54 @@
  *  This file is part of DrumGizmo.
  *
  *  DrumGizmo is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  DrumGizmo is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#ifndef __DRUMGIZMO_LABEL_H__
-#define __DRUMGIZMO_LABEL_H__
+#pragma once
 
 #include "widget.h"
 
-#include <string>
+#include "font.h"
 
-#include "guievent.h"
+#include <string>
 
 namespace GUI {
 
+enum class TextAlignment {
+	left,
+	center,
+	right,
+};
+
 class Label : public Widget {
 public:
-  Label(Widget *parent);
+	Label(Widget *parent);
 
-  void setText(std::string text);
+	void setText(const std::string& text);
 
-  //protected:
-  virtual void repaintEvent(RepaintEvent *e);
+	void setAlignment(TextAlignment alignment);
+
+	void resizeToText();
+
+protected:
+	// From Widget:
+	virtual void repaintEvent(RepaintEvent* repaintEvent) override;
 
 private:
-  std::string _text;
+	std::string _text;
+	Font font{":fontemboss.png"};
+	TextAlignment alignment{TextAlignment::left};
+	int border{0};
 };
 
-};
-
-#endif/*__DRUMGIZMO_LABEL_H__*/
+} // GUI::
