@@ -32,10 +32,14 @@
 #include "widget.h"
 #include "painter.h"
 #include "listboxbasic.h"
+#include "texturedbox.h"
 
-namespace GUI {
+namespace GUI
+{
 
-class ListBox : public Widget {
+class ListBox
+	: public Widget
+{
 public:
 	ListBox(Widget *parent);
 	~ListBox();
@@ -61,7 +65,10 @@ public:
 private:
 	ListBoxBasic basic;
 
-	Painter::Box box;
+	TexturedBox box{getImageCache(), ":widget.png",
+			0, 0, // atlas offset (x, y)
+			7, 1, 7, // dx1, dx2, dx3
+			7, 63, 7}; // dy1, dy2, dy3
 };
 
 } // GUI::
