@@ -29,11 +29,12 @@
 #include <string.h>
 #include <vector>
 
+#include <notifier.h>
+
 #include "widget.h"
 #include "font.h"
 #include "painter.h"
 #include "scrollbar.h"
-#include "notifier.h"
 
 namespace GUI {
 
@@ -77,7 +78,7 @@ protected:
 
 	ScrollBar scroll;
 
-	Image bg_img;
+	Texture bg_img{getImageCache(), ":widget.png", 7, 7, 1, 63};
 
 	void setSelection(int index);
 
