@@ -29,14 +29,19 @@
 #include <string.h>
 #include <vector>
 
+#include <notifier.h>
+
 #include "widget.h"
 #include "painter.h"
 #include "listboxbasic.h"
-#include "notifier.h"
+#include "texturedbox.h"
 
-namespace GUI {
+namespace GUI
+{
 
-class ListBoxThin : public Widget {
+class ListBoxThin
+	: public Widget
+{
 public:
 	ListBoxThin(Widget *parent);
 	~ListBoxThin();
@@ -61,7 +66,10 @@ public:
 private:
 	ListBoxBasic basic;
 
-	Painter::Box box;
+	TexturedBox box{getImageCache(), ":thinlistbox.png",
+			0, 0, // atlas offset (x, y)
+			1, 1, 1, // dx1, dx2, dx3
+			1, 1, 1}; // dy1, dy2, dy3
 };
 
 } // GUI::
