@@ -69,7 +69,8 @@ void PixelBuffer::setPixel(size_t x, size_t y,
 }
 
 PixelBufferAlpha::PixelBufferAlpha(size_t width, size_t height)
-	: buf(nullptr)
+	: managed(true)
+	, buf(nullptr)
 	, x(0)
 	, y(0)
 {
@@ -78,7 +79,10 @@ PixelBufferAlpha::PixelBufferAlpha(size_t width, size_t height)
 
 PixelBufferAlpha::~PixelBufferAlpha()
 {
-	free(buf);
+	if(managed)
+	{
+		free(buf);
+	}
 }
 
 void PixelBufferAlpha::realloc(size_t width, size_t height)
@@ -142,9 +146,10 @@ void PixelBufferAlpha::addPixel(size_t x, size_t y,
 	buf[PX(3)] = (a + b) * 255;
 }
 
-void PixelBufferAlpha::addPixel(size_t x, size_t y, Colour c)
+void PixelBufferAlpha::addPixel(size_t x, size_t y, const Colour& c)
 {
-	addPixel(x, y, c.red * 255, c.green * 255, c.blue * 255, c.alpha * 255);
+	addPixel(x, y,
+	         c.red() * 255, c.green() * 255, c.blue() * 255, c.alpha() * 255);
 }
 
 void PixelBufferAlpha::pixel(size_t x, size_t y,
