@@ -30,8 +30,10 @@
 
 #include "guievent.h"
 #include "painter.h"
+#include "texturedbox.h"
 
-namespace GUI {
+namespace GUI
+{
 
 enum class ProgressBarState
 {
@@ -41,13 +43,15 @@ enum class ProgressBarState
 	Off
 };
 
-class ProgressBar : public Widget {
+class ProgressBar
+	: public Widget
+{
 public:
-	ProgressBar(Widget *parent);
+	ProgressBar(Widget* parent);
 	~ProgressBar();
 
-	float progress();
-	void setProgress(float progress);
+	void setTotal(std::size_t total);
+	void setValue(std::size_t value);
 
 	void setState(ProgressBarState state);
 
@@ -56,15 +60,30 @@ protected:
 	virtual void repaintEvent(RepaintEvent* repaintEvent) override;
 
 private:
-	ProgressBarState state;
+	ProgressBarState state{ProgressBarState::Blue};
 
-	Painter::Bar bar_bg;
+	TexturedBox bar_bg{getImageCache(), ":progress.png",
+			0, 0, // atlas offset (x, y)
+			6, 1, 6, // dx1, dx2, dx3
+			11, 0, 0}; // dy1, dy2, dy3
 
-	Painter::Bar bar_green;
-	Painter::Bar bar_blue;
-	Painter::Bar bar_red;
+	TexturedBox bar_red{getImageCache(), ":progress.png",
+			13, 0, // atlas offset (x, y)
+			2, 1, 2, // dx1, dx2, dx3
+			11, 0, 0}; // dy1, dy2, dy3
 
-	float _progress;
+	TexturedBox bar_green{getImageCache(), ":progress.png",
+			18, 0, // atlas offset (x, y)
+			2, 1, 2, // dx1, dx2, dx3
+			11, 0, 0}; // dy1, dy2, dy3
+
+	TexturedBox bar_blue{getImageCache(), ":progress.png",
+			23, 0, // atlas offset (x, y)
+			2, 1, 2, // dx1, dx2, dx3
+			11, 0, 0}; // dy1, dy2, dy3
+
+	std::size_t total{0};
+	std::size_t value{0};
 };
 
 } // GUI::
