@@ -11,16 +11,16 @@
  *  This file is part of DrumGizmo.
  *
  *  DrumGizmo is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  DrumGizmo is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
@@ -28,14 +28,24 @@
 
 #include "painter.h"
 
-GUI::VerticalLine::VerticalLine(GUI::Widget *parent)
-  : Widget(parent), vline(":vertline.png")
+namespace GUI {
+
+VerticalLine::VerticalLine(Widget *parent)
+	: Widget(parent)
+	, vline(":vertline.png")
 {
 }
 
-void GUI::VerticalLine::repaintEvent(RepaintEvent *e)
+void VerticalLine::repaintEvent(RepaintEvent* repaintEvent)
 {
-  (void)e;
-  GUI::Painter p(this);
-  p.drawImageStretched(0, 0, &vline, width(), height());
+	if(height() < 2)
+	{
+		return;
+	}
+
+	Painter p(*this);
+	p.drawImageStretched(0, (height() - vline.height()) / 2,
+	                     vline, width(), vline.height());
 }
+
+} // GUI::
