@@ -26,11 +26,11 @@
  */
 #include "widget.h"
 
+#include <cassert>
+
 #include "painter.h"
 #include "window.h"
 
-#include <stdio.h>
-
 namespace GUI {
 
 Widget::Widget(Widget* parent)
@@ -133,6 +133,27 @@ size_t Widget::height()
 	return _height;
 }
 
+PixelBufferAlpha& Widget::GetPixelBuffer()
+{
+	return pixbuf;
+}
+
+void Widget::beginPaint()
+{
+	if(_window)
+	{
+		_window->beginPaint();
+	}
+}
+
+void Widget::endPaint()
+{
+	if(_window)
+	{
+		_window->endPaint();
+	}
+}
+
 size_t Widget::windowX()
 {
 	size_t window_x = x();
@@ -155,6 +176,12 @@ size_t Widget::windowY()
 	return window_y;
 }
 
+ImageCache& Widget::getImageCache()
+{
+	assert(parent);
+	return parent->getImageCache();
+}
+
 Widget* Widget::find(int x, int y)
 {
 	for(auto i = children.rbegin(); i != children.rend(); ++i)
