@@ -30,14 +30,21 @@
 #include "pixelbuffer.h"
 #include "notifier.h"
 #include "layout.h"
+#include "canvas.h"
 
 #include <vector>
 
-namespace GUI {
+namespace GUI
+{
 
+class ImageCache;
 class Window;
 
-class Widget : public Listener, public LayoutItem {
+class Widget
+	: public Listener
+	, public LayoutItem
+	, public Canvas
+{
 	friend class Painter;
 public:
 	Widget(Widget* parent);
@@ -54,6 +61,11 @@ public:
 	virtual size_t width() override;
 	virtual size_t height() override;
 
+	// From Canvas
+	PixelBufferAlpha& GetPixelBuffer() override;
+	void beginPaint() override;
+	void endPaint() override;
+
 	virtual size_t windowX();
 	virtual size_t windowY();
 
@@ -71,6 +83,8 @@ public:
 	virtual void mouseLeaveEvent() {}
 	virtual void mouseEnterEvent() {}
 
+	virtual ImageCache& getImageCache();
+
 	Widget* find(int x, int y);
 
 	virtual Window* window();
