@@ -32,12 +32,16 @@
 #include "nativewindow.h"
 #include "image.h"
 #include "eventhandler.h"
+#include "imagecache.h"
 
-namespace GUI {
+namespace GUI
+{
 
-class Window : public Widget {
+class Window
+	: public Widget
+{
 public:
-	Window(void* native_window);
+	Window(void* native_window = nullptr);
 	~Window();
 
 	void setFixedSize(int width, int height);
@@ -52,6 +56,8 @@ public:
 	void hide() override;
 	Window* window() override;
 
+	ImageCache& getImageCache() override;
+
 	EventHandler* eventHandler();
 
 	Widget* keyboardFocus();
@@ -71,7 +77,7 @@ protected:
 	void updateBuffer();
 
 	// For the Painter
-	friend class Painter;
+	friend class Widget;
 	void beginPaint();
 	void endPaint();
 
@@ -91,6 +97,8 @@ protected:
 	EventHandler* eventhandler{nullptr};
 
 	size_t maxRefcount{0};
+
+	ImageCache image_cache;
 };
 
 } // GUI::
