@@ -28,53 +28,39 @@
 
 #include <string>
 #include <list>
+#include <array>
 
 #include "audiooutputengine.h"
 #include "audioinputengine.h"
-
 #include "events.h"
 #include "audiofile.h"
 #include "drumkit.h"
-#include "memchecker.h"
-
 #include "drumkitloader.h"
 #include "audiocache.h"
-
 #include "mutex.h"
-
-#include "message.h"
-
-#include "messagereceiver.h"
-
 #include "chresampler.h"
+#include "settings.h"
+#include "inputprocessor.h"
 
-#include "configfile.h"
-
-#define MAX_NUM_CHANNELS 64
 #define REFSFILE "refs.conf"
-#define RESAMPLER_INPUT_BUFFER 64
 
 class DrumGizmo
-	: public MessageReceiver
 {
 public:
-	DrumGizmo(AudioOutputEngine *outputengine, AudioInputEngine *inputengine);
+	DrumGizmo(Settings& settings,
+	          AudioOutputEngine& outputengine,
+	          AudioInputEngine& inputengine);
 	virtual ~DrumGizmo();
 
-	bool loadkit(std::string kitfile);
-
 	bool init();
 
-	void run(int endpos);
 	bool run(size_t pos, sample_t *samples, size_t nsamples);
 	void stop();
 
 	void getSamples(int ch, int pos, sample_t *s, size_t sz);
 
-	std::string configString();
-	bool setConfigString(std::string cfg);
-
-	void handleMessage(Message *msg);
+	//! Get the current engine latency in samples.
+	std::size_t getLatency() const;
 
 	int samplerate();
 	void setSamplerate(int samplerate);
@@ -83,29 +69,37 @@ public:
 
 	void setFreeWheel(bool freewheel);
 
+	void setRandomSeed(unsigned int seed);
+
+private:
+	static constexpr int MAX_NUM_CHANNELS = 64;
+	static constexpr int RESAMPLER_OUTPUT_BUFFER = 4096;
+	static constexpr int RESAMPLER_INPUT_BUFFER = 64;
+
 protected:
 	DrumKitLoader loader;
 
 	Mutex mutex;
-	bool is_stopping; ///< Is set to true when a TYPE_STOP event has been seen.
 
-	AudioOutputEngine *oe;
-	AudioInputEngine *ie;
+	AudioOutputEngine& oe;
+	AudioInputEngine& ie;
 
 	std::list< Event* > activeevents[MAX_NUM_CHANNELS];
 
-	CHResampler resampler[MAX_NUM_CHANNELS];
-	sample_t resampler_output_buffer[MAX_NUM_CHANNELS][4096];
+	Resamplers resamplers;
+	sample_t resampler_output_buffer[MAX_NUM_CHANNELS][RESAMPLER_OUTPUT_BUFFER];
 	sample_t resampler_input_buffer[MAX_NUM_CHANNELS][RESAMPLER_INPUT_BUFFER];
 
 	std::map<std::string, AudioFile *> audiofiles;
 
 	AudioCache audioCache;
 	DrumKit kit;
-	MemChecker memchecker;
+	InputProcessor input_processor;
 
 	size_t framesize;
 	bool freewheel;
-	
+
 	std::vector<event_t> events;
+	Settings& settings;
+	Random rand;
 };
