@@ -28,69 +28,47 @@
 
 DrumKit::DrumKit()
 {
-  magic = this;
+	magic = this;
 }
 
 DrumKit::~DrumKit()
 {
-  magic = NULL;
-  clear();
+	magic = NULL;
+	clear();
 }
 
 void DrumKit::clear()
 {
-  Instruments::iterator i = instruments.begin();
-  while(i != instruments.end()) {
-    delete *i;
-    i++;
-  }
-  instruments.clear();
+	instruments.clear();
 
-  channels.clear();
+	channels.clear();
 
-  _name = "";
-  _description = "";
-  _samplerate = 44100;
+	_name = "";
+	_description = "";
+	_samplerate = 44100;
 }
 
-bool DrumKit::isValid()
+bool DrumKit::isValid() const
 {
-  return this == magic;
+	return this == magic;
 }
 
-std::string DrumKit::file()
+std::string DrumKit::getFile() const
 {
-  return _file;
+	return _file;
 }
 
-std::string DrumKit::name()
+std::string DrumKit::getName() const
 {
-  return _name;
+	return _name;
 }
 
-std::string DrumKit::description()
+std::string DrumKit::getDescription() const
 {
-  return _description;
+	return _description;
 }
 
-size_t DrumKit::samplerate()
+size_t DrumKit::getSamplerate() const
 {
-  return _samplerate;
+	return _samplerate;
 }
-
-#ifdef TEST_DRUMKIT
-//Additional dependency files
-//deps:
-//Required cflags (autoconf vars may be used)
-//cflags:
-//Required link options (autoconf vars may be used)
-//libs:
-#include "test.h"
-
-TEST_BEGIN;
-
-// TODO: Put some testcode here (see test.h for usable macros).
-
-TEST_END;
-
-#endif/*TEST_DRUMKIT*/
