@@ -28,12 +28,17 @@
 
 #include <string>
 #include <list>
+#include <mutex>
+#include "mutex.h"
 
 #include "thread.h"
 #include "semaphore.h"
-#include "mutex.h"
 
 #include "drumkit.h"
+#include "settings.h"
+#include "audioinputengine.h"
+#include "chresampler.h"
+#include "memchecker.h"
 
 //! This class is responsible for loading the drumkits in its own thread.
 //! All interaction calls are simply modifying queues and not doing any
@@ -44,42 +49,47 @@ class DrumKitLoader
 	: public Thread
 {
 public:
-	//! The constrcutor starts the loader thread.
-	DrumKitLoader();
+	DrumKitLoader(Settings& settings, DrumKit& kit, AudioInputEngine& ie,
+	              Resamplers& resamplers, Random& rand);
 
-	//! The destructor signals the thread to stop and waits to merge before
-	//! returning (ie. deleting the object will garantuee that the thread has
-	//! been stopped).
 	~DrumKitLoader();
 
-	//! Signal the loader to start loading all audio files contained in kit.
+	//! Starts the loader thread.
+	void init();
+
+	//! Signal the loader thread to stop and waits for the threads to merge
+	//! before returning.
+	void deinit();
+
+	bool loadkit(const std::string& file);
+
+	//! Signal the loader to start loading all audio files contained in the kit.
 	//! All other AudioFiles in queue will be removed before the new ones are
 	//! scheduled.
 	void loadKit(DrumKit *kit);
 
-	void thread_main();
-
-	//! Simply reports if the load queue is empty (i.e. all AudioFiles has been
-	//! loaded).
-	bool isDone();
-
-	//! Signal the loader to stop and wait until it has.
-	void stop();
-
 	//! Skip all queued AudioFiles.
 	void skip();
 
+	//! Set the framesize which will be used to preloading samples in next
+	//! loadKit call.
 	void setFrameSize(size_t framesize);
 
 protected:
+	void thread_main();
+
 	Semaphore run_semaphore;
 	Semaphore semaphore;
 	Semaphore framesize_semaphore;
-	Mutex mutex;
+	std::mutex mutex;
 	volatile bool running{false};
 	std::list<AudioFile*> load_queue;
-	size_t total_num_audiofiles{0};
-	size_t fraction{1};
-	size_t loaded{0};
-	size_t framesize{0};
+	std::size_t framesize{0};
+	Settings& settings;
+	SettingsGetter getter;
+	DrumKit& kit;
+	AudioInputEngine& ie;
+	Resamplers& resamplers;
+	MemChecker memchecker;
+	Random& rand;
 };
