@@ -24,37 +24,34 @@
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#ifndef __DRUMGIZMO_DRUMKITPARSER_H__
-#define __DRUMGIZMO_DRUMKITPARSER_H__
+#pragma once
 
 #include "saxparser.h"
 #include "drumkit.h"
 #include "configfile.h"
 
-class DrumKitParser : public SAXParser {
+class DrumKitParser
+	: public SAXParser
+{
 public:
-  DrumKitParser(const std::string &kitfile, DrumKit &kit);
-  ~DrumKitParser();
+	DrumKitParser(Settings& setting, DrumKit& kit, Random& rand);
 
-  void startTag(std::string name,
-                std::map< std::string, std::string> attributes);
-  void endTag(std::string name);
+	virtual int parseFile(const std::string& filename) override;
 
 protected:
-  int readData(char *data, size_t size);
+	void startTag(const std::string& name, const attr_t& attributes) override;
+	void endTag(const std::string& name) override;
 
 private:
-  FILE *fd;
-  DrumKit &kit;
-  //  Instrument *instr;
-  std::string path;
+	DrumKit& kit;
+	std::string path;
 
-  std::map<std::string, std::string> channelmap;
-  std::string instr_file;
-  std::string instr_name;
-  std::string instr_group;
+	std::unordered_map<std::string, std::string> channelmap;
+	std::string instr_file;
+	std::string instr_name;
+	std::string instr_group;
 
-  ConfigFile refs;
+	ConfigFile refs;
+	Settings& settings;
+	Random& rand;
 };
-
-#endif/*__DRUMGIZMO_DRUMKITPARSER_H__*/
