@@ -24,61 +24,64 @@
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#ifndef __DRUMGIZMO_INSTRUMENT_H__
-#define __DRUMGIZMO_INSTRUMENT_H__
+#pragma once
 
 #include <string>
 #include <vector>
+#include <memory>
 
 #include "rangemap.h"
 #include "powerlist.h"
 
 #include "sample.h"
 #include "versionstr.h"
+#include "random.h"
 
-class InstrumentParser;
-class Instrument {
-  friend class InstrumentParser;
+#include "settings.h"
+
+class Instrument
+{
+	friend class InstrumentParser;
 public:
-  Instrument();
-  ~Instrument();
+	Instrument(Settings& settings, Random& rand);
+	~Instrument();
 
-  Sample *sample(level_t level, size_t pos);
+	Sample* sample(level_t level, size_t pos);
 
-  std::string name();
-  std::string description();
-  std::string group();
+	std::string getName() const;
+	std::string getDescription() const;
+	std::string getGroup() const;
 
-  void setGroup(std::string group);
+	void setGroup(const std::string& group);
 
-  //  std::map<std::string, std::string> channelmap;
+	//  std::map<std::string, std::string> channelmap;
 
-  std::vector<AudioFile*> audiofiles;
+	std::vector<std::unique_ptr<AudioFile>> audiofiles;
 
-  bool isValid();
+	bool isValid() const;
 
 private:
-  void *magic;
+	void* magic;
 
-  std::string _group;
-  std::string _name;
-  std::string _description;
+	std::string _group;
+	std::string _name;
+	std::string _description;
 
-  VersionStr version;
+	VersionStr version;
 
-  RangeMap<level_t, Sample*> samples;
-  PowerList powerlist;
+	RangeMap<level_t, Sample*> samples;
 
-  void addSample(level_t a, level_t b, Sample *s);
-  void finalise(); ///< Signal instrument that no more samples will be added.
+	void addSample(level_t a, level_t b, Sample* s);
+	void finalise(); ///< Signal instrument that no more samples will be added.
 
-  std::vector<Sample*> samplelist;
+	std::vector<Sample*> samplelist;
 
-  size_t lastpos;
-  float mod;
+	size_t lastpos;
+	float mod;
+	Settings& settings;
+	Random& rand;
+	PowerList powerlist;
 };
 
-//typedef std::map< std::string, Instrument > Instruments;
-typedef std::vector< Instrument* > Instruments;
-
-#endif/*__DRUMGIZMO_INSTRUMENT_H__*/
+// typedef std::map< std::string, Instrument > Instruments;
+using Instruments = std::vector<std::unique_ptr<Instrument>>;
