@@ -24,23 +24,29 @@
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#ifndef __DRUMGIZMO_MIDIMAPPER_H__
-#define __DRUMGIZMO_MIDIMAPPER_H__
+#pragma once
 
 #include <map>
 #include <string>
+#include <mutex>
+#include "mutex.h"
 
 typedef std::map<int, std::string> midimap_t;
 typedef std::map<std::string, int> instrmap_t;
 
-class MidiMapper {
+class MidiMapper
+{
 public:
-  void clear();
+	//! Lookup note in map and return its index.
+	//! \returns -1 if not found or the note index.
+	int lookup(int note);
 
-  int lookup(int note);
+	//! Set new map sets.
+	void swap(instrmap_t& instrmap, midimap_t& midimap);
 
-  instrmap_t instrmap;
-  midimap_t midimap;
+private:
+	instrmap_t instrmap;
+	midimap_t midimap;
+
+	std::mutex mutex;
 };
-
-#endif/*__DRUMGIZMO_MIDIMAPPER_H__*/
