@@ -31,55 +31,37 @@
 
 #include <sndfile.h>
 
-Sample::Sample(std::string name, float power)
+Sample::Sample(const std::string& name, float power)
+	: name{name}
+	, power{power}
+	, audiofiles{}
 {
-  this->name = name;
-  this->power = power;
 }
 
 Sample::~Sample()
 {
 }
 
-void Sample::addAudioFile(Channel *c, AudioFile *a)
+void Sample::addAudioFile(Channel* c, AudioFile* a)
 {
-  audiofiles[c] = a;
+	audiofiles[c] = a;
 }
 
-AudioFile *Sample::getAudioFile(Channel *c)
+AudioFile* Sample::getAudioFile(Channel* c)
 {
-  /*
-  if(audiofiles.find(c) == audiofiles.end()) return NULL;
-  return audiofiles[c];
-  */
+	/*
+	if(audiofiles.find(c) == audiofiles.end()) return nullptr;
+	return audiofiles[c];
+	*/
 
-  AudioFiles::iterator i = audiofiles.begin();
-  while(i != audiofiles.end()) {
-    Channel *ch = i->first;
-    if(c->num == ch->num) return i->second;
-    i++;
-  }
+	// todo: std::find_if ??
+	for (auto& pair: audiofiles)
+	{
+		if (pair.first->num == c->num)
+		{
+			return pair.second;
+		}
+	}
 
-  return NULL;
+	return nullptr;
 }
-
-#ifdef TEST_SAMPLE
-//deps: channel.cc audiofile.cc
-//cflags: $(SNDFILE_CFLAGS)
-//libs: $(SNDFILE_LIBS)
-#include "test.h"
-
-TEST_BEGIN;
-
-Sample s;
-InstrumentChannel c;
-InstrumentChannel c2;
-AudioFile a("test");
-
-s.addAudioFile(&c, &a);
-TEST_EQUAL(s.getAudioFile(&c), &a, "?");
-TEST_EQUAL(s.getAudioFile(&c2), NULL, "?");
-
-TEST_END;
-
-#endif/*TEST_SAMPLE*/
